==> aws-backup-client-0.0.4.tar.gz: aws-backup-client-0.0.4/aws_backup/client/ec2.py <==
# coding: utf-8
import boto3

from .base import BaseClient
from ..exceptions import OptionDoesNotEnough


class Ec2Client(BaseClient):
    resource_service = 'ec2'

    def __init__(self, *args, **kwargs):
        super(Ec2Client, self).__init__(*args, **kwargs)

        if not (self.options.instance_id or self.options.instance_name or self.options.instance_tag):
            raise OptionDoesNotEnough('Any of input is required: --instance-id, --instance-name, --instance-tag')

    @property
    def instances(self):
        filters = [
            {'Name': 'tag:{}'.format(k), 'Values': ['{}'.format(v)]}
            for k, v in (kv.split('/') for kv in self.options.instance_tag or [])
        ]
        if self.options.instance_name:
            filters.append({'Name': 'tag:Name',
                            'Values': self.options.instance_name or []})

        return self.resource.instances.filter(
            InstanceIds=self.options.instance_id or [],
            Filters=filters)

    def create_image(self, instance):
        try:
            image = instance.create_image(
                Name=self.generate_code(instance.id),
                Description=self.options.image_description,
                NoReboot=not(self.options.reboot),
                DryRun=self.options.dry_run
            )
            self.logger.debug('* instance.tags: %s', instance.tags)
            image.create_tags(DryRun=self.options.dry_run, Tags=instance.tags)

            self.logger.info(
                '* created image: %s (%s)', image.name, image.id)
            return image
        except boto3.exceptions.botocore.exceptions.ClientError as e:
            self.logger.error(e)

    def delete_images(self, instance):
        if not (self.options.image_max_number or self.options.image_expiration):
            return

        for index, image in enumerate(sorted(
            self.resource.images.filter(Filters=[{'Name': 'name', 'Values': [
                self.generate_query(instance.id)]}]),
            reverse=True, key=lambda i: i.creation_date
        ), start=1):
            self.logger.debug('* image.creation_date: %s', image.creation_date)
            cdate = self.parse_cdate(image.creation_date)
            if (
                (not self.options.image_max_number or index > self.options.image_max_number) and
                (not self.options.image_expiration or cdate + self.options.image_expiration < self.now)
            ):
                try:
                    name = image.name
                    image.deregister(DryRun=self.options.dry_run)
                    self.logger.info(
                        '* deleted image: %s (%s)', name, image.id)
                except boto3.exceptions.botocore.exceptions.ClientError as e:
                    self.logger.error(e)

==> aws-backup-client-0.0.6.tar.gz: aws-backup-client-0.0.6/aws_backup/client/ec2.py <==
# coding: utf-8
import boto3

from .base import BaseClient
from ..exceptions import OptionDoesNotEnough


class Ec2Client(BaseClient):
    resource_service = 'ec2'

    def __init__(self, *args, **kwargs):
        super(Ec2Client, self).__init__(*args, **kwargs)

        if not (self.options.instance_id or self.options.instance_name or self.options.instance_tag):
            raise OptionDoesNotEnough('Any of input is required: --instance-id, --instance-name, --instance-tag')

    @property
    def instances(self):
        filters = [
            {'Name': 'tag:{}'.format(k), 'Values': ['{}'.format(v)]}
            for k, v in (kv.split('/') for kv in self.options.instance_tag or [])
        ]
        if self.options.instance_name:
            filters.append({'Name': 'tag:Name',
                            'Values': self.options.instance_name or []})

        return self.resource.instances.filter(
            InstanceIds=self.options.instance_id or [],
            Filters=filters)

    def create_image(self, instance):
        try:
            image = instance.create_image(
                Name=self.generate_code(instance.id),
                Description=self.options.image_description,
                NoReboot=not self.options.reboot,
                DryRun=self.options.dry_run
            )
            self.logger.debug('* instance.tags: %s', instance.tags)
            if instance.tags:
                image.create_tags(DryRun=self.options.dry_run, Tags=instance.tags)

            self.logger.info('* created image: %s (%s)', image.name, image.id)
            return image
        except boto3.exceptions.botocore.exceptions.ClientError as e:
            self.logger.error(e)

    def delete_images(self, instance):
        if not (self.options.image_max_number or self.options.image_expiration):
            return

        for index, image in enumerate(sorted(
            self.resource.images.filter(Filters=[{'Name': 'name', 'Values': [
                self.generate_query(instance.id)]}]),
            reverse=True, key=lambda i: i.creation_date
        ), start=1):
            self.logger.debug('* image.creation_date: %s', image.creation_date)
            cdate = self.parse_cdate(image.creation_date)

            if (
                (not self.options.image_max_number or index > self.options.image_max_number) and
                (not self.options.image_expiration or cdate + self.options.image_expiration < self.now)
            ):
                try:
                    name = image.name
                    snapshot_ids = [s['Ebs']['SnapshotId'] for s in image.block_device_mappings]
                    if self.options.keep_snapshot or not snapshot_ids:
                        delete_snapshots = []
                    else:
                        delete_snapshots = self.resource.snapshots.filter(SnapshotIds=snapshot_ids)

                    image.deregister(DryRun=self.options.dry_run)
                    self.logger.info('* deleted image: %s (%s)', name, image.id)
                    for snapshot in delete_snapshots:
                        snapshot.delete(DryRun=self.options.dry_run)
                        self.logger.info('  * deleted snapshot: %s', snapshot.id)

                except boto3.exceptions.botocore.exceptions.ClientError as e:
                    self.logger.error(e)
